define(
//begin v1.x content
{
	"field-quarter-short-relative+0": "questo trim.",
	"field-quarter-short-relative+1": "trim. prossimo",
	"field-tue-relative+-1": "martedì scorso",
	"field-year": "anno",
	"field-wed-relative+0": "questo mercoledì",
	"field-wed-relative+1": "mercoledì prossimo",
	"field-minute": "minuto",
	"field-month-narrow-relative+-1": "mese scorso",
	"field-tue-narrow-relative+0": "questo mar.",
	"field-tue-narrow-relative+1": "mar. prossimo",
	"field-thu-short-relative+0": "questo gio.",
	"field-day-short-relative+-1": "ieri",
	"dateTimeFormat-short": "{1}, {0}",
	"field-thu-short-relative+1": "gio. prossimo",
	"field-day-relative+0": "oggi",
	"field-day-short-relative+-2": "l’altro ieri",
	"field-day-relative+1": "domani",
	"field-week-narrow-relative+0": "questa sett.",
	"field-day-relative+2": "dopodomani",
	"field-week-narrow-relative+1": "sett. prossima",
	"field-wed-narrow-relative+-1": "mer. scorso",
	"field-year-narrow": "anno",
	"field-era-short": "era",
	"field-year-narrow-relative+0": "quest’anno",
	"field-tue-relative+0": "questo martedì",
	"field-year-narrow-relative+1": "anno prossimo",
	"field-tue-relative+1": "martedì prossimo",
	"field-weekdayOfMonth": "giorno del mese",
	"field-second-short": "s",
	"dayPeriods-format-narrow-am": "m.",
	"dateFormatItem-MMMd": "d MMM",
	"field-weekdayOfMonth-narrow": "giorno mese",
	"field-week-relative+0": "questa settimana",
	"field-month-relative+0": "questo mese",
	"field-week-relative+1": "settimana prossima",
	"field-month-relative+1": "mese prossimo",
	"field-sun-narrow-relative+0": "questa dom.",
	"field-mon-short-relative+0": "questo lun.",
	"field-sun-narrow-relative+1": "dom. prossima",
	"field-mon-short-relative+1": "lun. prossimo",
	"field-second-relative+0": "ora",
	"dateFormatItem-yyyyQQQ": "QQQ y G",
	"months-standAlone-narrow": [
		"G",
		"F",
		"M",
		"A",
		"M",
		"G",
		"L",
		"A",
		"S",
		"O",
		"N",
		"D"
	],
	"eraNames": [
		"EB"
	],
	"field-weekOfMonth": "settimana del mese",
	"field-month-short": "mese",
	"dateFormatItem-GyMMMEd": "E d MMM y G",
	"dateFormatItem-yyyyMd": "d/M/y GGGGG",
	"field-day": "giorno",
	"field-dayOfYear-short": "giorno anno",
	"field-year-relative+-1": "anno scorso",
	"field-sat-short-relative+-1": "sab. scorso",
	"field-hour-relative+0": "quest’ora",
	"dateFormatItem-yyyyMEd": "E d/M/y GGGGG",
	"field-wed-relative+-1": "mercoledì scorso",
	"dateTimeFormat-medium": "{1}, {0}",
	"field-sat-narrow-relative+-1": "sab. scorso",
	"field-second": "secondo",
	"days-standAlone-narrow": [
		"D",
		"L",
		"M",
		"M",
		"G",
		"V",
		"S"
	],
	"dateFormat-long": "dd MMMM y G",
	"dateFormatItem-GyMMMd": "d MMM y G",
	"field-quarter": "trimestre",
	"field-week-short": "sett.",
	"field-day-narrow-relative+0": "oggi",
	"field-day-narrow-relative+1": "domani",
	"field-day-narrow-relative+2": "dopodomani",
	"quarters-standAlone-wide": [
		"1º trimestre",
		"2º trimestre",
		"3º trimestre",
		"4º trimestre"
	],
	"days-format-narrow": [
		"D",
		"L",
		"M",
		"M",
		"G",
		"V",
		"S"
	],
	"field-tue-short-relative+0": "questo mar.",
	"field-tue-short-relative+1": "mar. prossimo",
	"field-month-short-relative+-1": "mese scorso",
	"field-mon-relative+-1": "lunedì scorso",
	"dateFormatItem-GyMMM": "MMM y G",
	"field-month": "mese",
	"field-day-narrow": "g.",
	"field-minute-short": "min",
	"field-dayperiod": "AM/PM",
	"field-sat-short-relative+0": "questo sab.",
	"field-sat-short-relative+1": "sab. prossimo",
	"dayPeriods-format-narrow-pm": "p.",
	"dateFormat-medium": "dd MMM y G",
	"dateFormatItem-yyyyMMMM": "MMMM y G",
	"eraAbbr": [
		"EB"
	],
	"quarters-standAlone-abbr": [
		"T1",
		"T2",
		"T3",
		"T4"
	],
	"dateFormatItem-yyyyM": "M/y GGGGG",
	"field-second-narrow": "s",
	"field-mon-relative+0": "questo lunedì",
	"field-mon-relative+1": "lunedì prossimo",
	"field-day-narrow-relative+-1": "ieri",
	"field-year-short": "anno",
	"field-day-narrow-relative+-2": "l’altro ieri",
	"months-format-narrow": [
		"G",
		"F",
		"M",
		"A",
		"M",
		"G",
		"L",
		"A",
		"S",
		"O",
		"N",
		"D"
	],
	"field-quarter-relative+-1": "trimestre scorso",
	"dateFormatItem-yyyyMMMd": "d MMM y G",
	"field-dayperiod-narrow": "AM/PM",
	"dayPeriods-standAlone-narrow-am": "m.",
	"field-week-narrow-relative+-1": "sett. scorsa",
	"days-format-short": [
		"dom",
		"lun",
		"mar",
		"mer",
		"gio",
		"ven",
		"sab"
	],
	"field-dayOfYear": "giorno dell’anno",
	"field-sat-relative+-1": "sabato scorso",
	"dateTimeFormat-long": "{1} 'alle' {0}",
	"dateFormatItem-Md": "d/M",
	"field-hour": "ora",
	"months-format-wide": [
		"gennaio",
		"febbraio",
		"marzo",
		"aprile",
		"maggio",
		"giugno",
		"luglio",
		"agosto",
		"settembre",
		"ottobre",
		"novembre",
		"dicembre"
	],
	"dateFormat-full": "EEEE d MMMM y G",
	"field-month-relative+-1": "mese scorso",
	"field-quarter-short": "trim.",
	"field-sat-narrow-relative+0": "questo sab.",
	"field-fri-relative+0": "questo venerdì",
	"field-sat-narrow-relative+1": "sab. prossimo",
	"field-fri-relative+1": "venerdì prossimo",
	"field-month-narrow-relative+0": "questo mese",
	"field-month-narrow-relative+1": "mese prossimo",
	"field-sun-short-relative+0": "questa dom.",
	"field-sun-short-relative+1": "dom. prossima",
	"field-week-relative+-1": "settimana scorsa",
	"field-quarter-short-relative+-1": "trim. scorso",
	"months-format-abbr": [
		"gen",
		"feb",
		"mar",
		"apr",
		"mag",
		"giu",
		"lug",
		"ago",
		"set",
		"ott",
		"nov",
		"dic"
	],
	"field-quarter-relative+0": "questo trimestre",
	"field-minute-relative+0": "questo minuto",
	"field-quarter-relative+1": "trimestre prossimo",
	"field-wed-short-relative+-1": "mer. scorso",
	"dateFormat-short": "dd/MM/yy GGGGG",
	"field-thu-short-relative+-1": "gio. scorso",
	"field-year-narrow-relative+-1": "anno scorso",
	"days-standAlone-wide": [
		"domenica",
		"lunedì",
		"martedì",
		"mercoledì",
		"giovedì",
		"venerdì",
		"sabato"
	],
	"dateFormatItem-yyyyMMMEd": "E d MMM y G",
	"field-mon-narrow-relative+-1": "lun. scorso",
	"dateFormatItem-MMMMd": "d MMMM",
	"field-thu-narrow-relative+-1": "gio. scorso",
	"field-tue-narrow-relative+-1": "mar. scorso",
	"field-weekOfMonth-short": "sett. mese",
	"dateFormatItem-yyyy": "y G",
	"dayPeriods-standAlone-narrow-pm": "p.",
	"field-wed-short-relative+0": "questo mer.",
	"months-standAlone-wide": [
		"gennaio",
		"febbraio",
		"marzo",
		"aprile",
		"maggio",
		"giugno",
		"luglio",
		"agosto",
		"settembre",
		"ottobre",
		"novembre",
		"dicembre"
	],
	"field-wed-short-relative+1": "mer. prossimo",
	"field-sun-relative+-1": "domenica scorsa",
	"days-standAlone-abbr": [
		"dom",
		"lun",
		"mar",
		"mer",
		"gio",
		"ven",
		"sab"
	],
	"dateTimeFormat-full": "{1} 'alle' {0}",
	"dateFormatItem-hm": "hh:mm a",
	"field-weekday": "giorno della settimana",
	"field-day-short-relative+0": "oggi",
	"field-quarter-narrow-relative+0": "questo trim.",
	"field-sat-relative+0": "questo sabato",
	"field-day-short-relative+1": "domani",
	"field-quarter-narrow-relative+1": "trim. prossimo",
	"field-sat-relative+1": "sabato prossimo",
	"field-day-short-relative+2": "dopodomani",
	"dateFormatItem-h": "hh a",
	"field-week-short-relative+0": "questa sett.",
	"field-week-short-relative+1": "sett. prossima",
	"months-standAlone-abbr": [
		"gen",
		"feb",
		"mar",
		"apr",
		"mag",
		"giu",
		"lug",
		"ago",
		"set",
		"ott",
		"nov",
		"dic"
	],
	"field-dayOfYear-narrow": "giorno anno",
	"field-month-short-relative+0": "questo mese",
	"field-month-short-relative+1": "mese prossimo",
	"field-weekdayOfMonth-short": "giorno mese",
	"dateFormatItem-MEd": "E d/M",
	"field-zone-narrow": "fuso",
	"dateFormatItem-y": "y G",
	"field-thu-narrow-relative+0": "questo gio.",
	"field-thu-narrow-relative+1": "gio. prossimo",
	"field-sun-narrow-relative+-1": "dom. scorsa",
	"field-mon-short-relative+-1": "lun. scorso",
	"field-thu-relative+0": "questo giovedì",
	"field-thu-relative+1": "giovedì prossimo",
	"field-fri-short-relative+-1": "ven. scorso",
	"dateFormatItem-hms": "hh:mm:ss a",
	"field-thu-relative+-1": "giovedì scorso",
	"field-week": "settimana",
	"quarters-format-wide": [
		"1º trimestre",
		"2º trimestre",
		"3º trimestre",
		"4º trimestre"
	],
	"dateFormatItem-Ed": "E d",
	"field-wed-narrow-relative+0": "questo mer.",
	"field-wed-narrow-relative+1": "mer. prossimo",
	"field-quarter-narrow-relative+-1": "trim. scorso",
	"field-year-short-relative+0": "quest’anno",
	"field-dayperiod-short": "AM/PM",
	"dateFormatItem-yyyyMMM": "MMM y G",
	"field-year-short-relative+1": "anno prossimo",
	"field-fri-short-relative+0": "questo ven.",
	"field-fri-short-relative+1": "ven. prossimo",
	"days-standAlone-short": [
		"dom",
		"lun",
		"mar",
		"mer",
		"gio",
		"ven",
		"sab"
	],
	"field-week-short-relative+-1": "sett. scorsa",
	"dateFormatItem-yyyyQQQQ": "QQQQ y G",
	"field-hour-short": "h",
	"field-zone-short": "fuso",
	"quarters-format-abbr": [
		"T1",
		"T2",
		"T3",
		"T4"
	],
	"field-month-narrow": "mese",
	"field-hour-narrow": "h",
	"field-fri-narrow-relative+-1": "ven. scorso",
	"field-year-relative+0": "quest’anno",
	"field-year-relative+1": "anno prossimo",
	"field-era-narrow": "era",
	"field-fri-relative+-1": "venerdì scorso",
	"eraNarrow": [
		"EB"
	],
	"field-tue-short-relative+-1": "mar. scorso",
	"field-minute-narrow": "min",
	"days-format-wide": [
		"domenica",
		"lunedì",
		"martedì",
		"mercoledì",
		"giovedì",
		"venerdì",
		"sabato"
	],
	"field-mon-narrow-relative+0": "questo lun.",
	"field-mon-narrow-relative+1": "lun. prossimo",
	"field-year-short-relative+-1": "anno scorso",
	"field-zone": "fuso orario",
	"dateFormatItem-MMMEd": "E d MMM",
	"field-weekOfMonth-narrow": "sett. mese",
	"field-weekday-narrow": "giorno sett.",
	"field-quarter-narrow": "trim.",
	"field-sun-short-relative+-1": "dom. scorsa",
	"field-day-relative+-1": "ieri",
	"field-day-relative+-2": "l’altro ieri",
	"field-weekday-short": "giorno settimana",
	"days-format-abbr": [
		"dom",
		"lun",
		"mar",
		"mer",
		"gio",
		"ven",
		"sab"
	],
	"field-sun-relative+0": "questa domenica",
	"field-sun-relative+1": "domenica prossima",
	"dateFormatItem-Gy": "y G",
	"field-day-short": "g.",
	"field-week-narrow": "sett.",
	"field-era": "era",
	"field-fri-narrow-relative+0": "questo ven.",
	"field-fri-narrow-relative+1": "ven. prossimo"
}
//end v1.x content
);